---
home: false
title: Motifs
layout: Layout
---

# {{ $frontmatter.title }}

Already 1979, Max Küchler started his part on Ahiqar (published in his study "Frühjüdische Weisheitstraditionen", Fribourg/Göttingen 1979) with a collection of topics in the Ahiqar-tale in note form. In relation to that, we have collected and tagged the central motifs and themes of this story that are present in the various transcriptions. This process helps to precise, correct and enlarge the motif history of this story. In the following, a short description of each motif is appended:

<!-- markdownlint-disable MD033 -->
<template>
  <v-simple-table>
    <template v-slot:default>
      <thead>
        <tr>
          <th class="text-left">
            Letter
          </th>
          <th class="text-left">
            Keyword
          </th>
          <th class="text-left">
            Category
          </th>
          <th class="text-left">
            Description
          </th>
        </tr>
      </thead>
      <tbody>
        <tr
          v-for="item in motifs"
          :key="item.letter"
        >
          <td>{{ item.letter }}</td>
          <td>{{ item.keyword }}</td>
          <td>{{ item.category }}</td>
          <td>{{ item.description }}</td>
        </tr>
      </tbody>
    </template>
  </v-simple-table>
</template>

<script>
  export default {
    data () {
      return {
        motifs: [
          {
            letter: 'A',
            keyword: 'Adherence to wisdom',
            category: 'Wisdom, knowledge',
            description: 'The necessity and Priority of being wise',
          },
          {
            letter: 'A',
            keyword: 'Air Castle',
            category: 'Riddle',
            description: 'The riddle of the air castle',
          },
          {
            letter: 'B',
            keyword: 'Beauty/Caducity',
            category: 'Women, caducity, social relationship',
            description: 'The relationship to women and the caducity of their beauty',
          },
          {
            letter: 'B',
            keyword: 'Burden/Debt',
            category: 'Commitment',
            description: 'The state of a person with commitments',
          },
          {
            letter: 'C',
            keyword: 'Caution against powerful',
            category: 'Social relationship',
            description: 'The relationship to powerful persons or forces',
          },
          {
            letter: 'D',
            keyword: 'Death age',
            category: 'Caducity, social standing, death, honour',
            description: 'The relationship to older persons and the caducity of human beings',
          },
          {
            letter: 'D',
            keyword: 'Discernment',
            category: 'Reflection, Behaviour',
            description: 'The righteous assessment of a situation',
          },
          {
            letter: 'D',
            keyword: 'Disciplining of son(s)',
            category: 'Social relationship, family',
            description: 'The instruction and education of one\'s sons',
          },
          {
            letter: 'E',
            keyword: 'Enemies',
            category: 'Social relationship',
            description: 'The relationship and attitude to adversial persons ',
          },
          {
            letter: 'G',
            keyword: 'Good name',
            category: 'Social standing, honour',
            description: 'The income of wise and righteous deeds',
          },
          {
            letter: 'I',
            keyword: 'Image king',
            category: 'Politics, king',
            description: 'The image of the Assyrian king',
          },
          {
            letter: 'I',
            keyword: 'Intrigue',
            category: 'Politics',
            description: 'Nadan\'s actions against Ahiqar',
          },
          {
            letter: 'K',
            keyword: 'Keeping secrets',
            category: 'Social relationship, Loyalty',
            description: 'How to handle secrets',
          },
          {
            letter: 'L',
            keyword: 'Loyal obligation to God(s)',
            category: 'God, Loyality',
            description: 'Allegiance and relation to God(s)',
          },
          {
            letter: 'M',
            keyword: 'Meekness showing respect',
            category: 'Social relationship',
            description: 'To behave with respect and meekness',
          },
          {
            letter: 'O',
            keyword: 'Obeying parents',
            category: 'Social relationship, Loyalty',
            description: 'Relationship to parents',
          },
          {
            letter: 'P',
            keyword: 'Parable animals',
            category: 'Parables, Animals',
            description: 'Parables including references to animals',
          },
          {
            letter: 'P',
            keyword: 'Parable plants',
            category: 'Parables, Plants',
            description: 'Parables including references to plants',
          },
          {
            letter: 'Q',
            keyword: 'Quarrel',
            category: 'Social relationship, social behaviour',
            description: 'How to handle conflicts and quarrels',
          },
          {
            letter: 'R',
            keyword: 'Richness poverty',
            category: 'Social position',
            description: 'The significance of richness resp. poverty',
          },
          {
            letter: 'R',
            keyword: 'Royal challenges',
            category: 'Politics',
            description: 'Political tasks for the king',
          },
          {
            letter: 'S',
            keyword: 'Self-examination, self-reflection',
            category: 'self-examination',
            description: 'Reflection on one\'s attitude and behaviour',
          },
          {
            letter: 'S',
            keyword: 'Social contacts family',
            category: 'Social relationship',
            description: 'Social contacts with persons within the family',
          },
          {
            letter: 'S',
            keyword: 'Social contacts no family',
            category: 'Social relationship',
            description: 'Social contacts with persons outside the family',
          },
          {
            letter: 'S',
            keyword: 'Successful courtier',
            category: 'Politics',
            description: 'Rehabilitation of Ahiqar',
          },
          {
            letter: 'T',
            keyword: 'Temptress women',
            category: 'Social relationship, women',
            description: 'Relationship to temptress women',
          },
          {
            letter: 'T',
            keyword: 'Treatment slaves',
            category: 'Social relationship',
            description: 'Relationship and treatment of slaves and maidservants',
          },
          {
            letter: 'T',
            keyword: 'Truth lying',
            category: 'Social behaviour',
            description: 'Attitude towards truth or falsehood',
          },
          {
            letter: 'W',
            keyword: 'Wise/fool/sinful behaviour resp. persons',
            category: 'wisdom, social behaviour, social relationship',
            description: 'Relation to wise, fool and sinful persons and their behaviour',
          },
        ],
      }
    },
  }
</script>
<!-- markdownlint-enable MD033 -->
